# compas_timber_pb

COMPAS Timber protobuf plugin

## Installation

Stable releases can be installed from PyPI.

```bash
pip install compas_timber_pb
```

To install the latest version for development, do:

```bash
git clone https://github.com/gramaziokohler/compas_timber_pb.git
cd compas_timber_pb
pip install -e .[dev]
```

## Documentation

For further "getting started" instructions, a tutorial, examples, and an API reference,
please check out the online documentation here: [compas_timber_pb docs](https://gramaziokohler.github.io/compas_timber_pb)

## Issue Tracker

If you find a bug or if you have a problem with running the code, please file an issue on the [Issue Tracker](https://github.com/gramaziokohler/compas_timber_pb/issues).
